https://bugs.gentoo.org/917532
https://gitlab.gnome.org/GNOME/gupnp-av/-/commit/9557768121d54fdcedabe7544863515d6a813354
https://gitlab.gnome.org/GNOME/gupnp-av/-/commit/1e10a41fcef6ae0d3e89958db89bc22398f3b4f1

From 9557768121d54fdcedabe7544863515d6a813354 Mon Sep 17 00:00:00 2001
From: Jens Georg <mail@jensge.org>
Date: Thu, 3 Aug 2023 23:52:43 +0200
Subject: [PATCH] Remove deprecates xmlRecoverMemory

Cannot currently remove xmlSchemaValidateStream as validateDoc fails to
accept the XSD
--- a/libgupnp-av/gupnp-didl-lite-parser.c
+++ b/libgupnp-av/gupnp-didl-lite-parser.c
@@ -230,12 +230,17 @@ gupnp_didl_lite_parser_parse_didl_recursive (GUPnPDIDLLiteParser *parser,
         GUPnPAVXMLDoc *xml_doc = NULL;
         gboolean       result;
 
-        doc = xmlRecoverMemory (didl, strlen (didl));
+        doc = xmlReadMemory (didl,
+                             strlen (didl),
+                             NULL,
+                             NULL,
+                             XML_PARSE_NONET | XML_PARSE_RECOVER);
         if (doc == NULL) {
                 g_set_error (error,
                              G_MARKUP_ERROR,
                              G_MARKUP_ERROR_PARSE,
-                             "Could not parse DIDL-Lite XML:\n%s", didl);
+                             "Could not parse DIDL-Lite XML:\n%s",
+                             didl);
 
                 return FALSE;
         }
--- a/libgupnp-av/gupnp-feature-list-parser.c
+++ b/libgupnp-av/gupnp-feature-list-parser.c
@@ -114,12 +114,17 @@ gupnp_feature_list_parser_parse_text
         xmlNode      *element;
         GList        *feature_list = NULL;
 
-        doc = xmlRecoverMemory (text, strlen (text));
+        doc = xmlReadMemory (text,
+                             strlen (text),
+                             NULL,
+                             NULL,
+                             XML_PARSE_NONET | XML_PARSE_RECOVER);
         if (doc == NULL) {
                 g_set_error (error,
                              G_MARKUP_ERROR,
                              G_MARKUP_ERROR_PARSE,
-                             "Could not parse FeatureList XML:\n%s", text);
+                             "Could not parse FeatureList XML:\n%s",
+                             text);
 
                 return NULL;
         }
-- 
GitLab

From 1e10a41fcef6ae0d3e89958db89bc22398f3b4f1 Mon Sep 17 00:00:00 2001
From: Jens Georg <mail@jensge.org>
Date: Sat, 25 Nov 2023 17:58:49 +0100
Subject: [PATCH] xml: Fix compatibility with libxml2 2.12.x

--- a/libgupnp-av/xml-util.h
+++ b/libgupnp-av/xml-util.h
@@ -16,6 +16,7 @@
 
 #include <glib.h>
 #include <libxml/tree.h>
+#include <libxml/parser.h>
 #include <stdarg.h>
 #include <glib-object.h>
 
-- 
GitLab
